==> keyclic_sdk_api-2.3.3.tar.gz: lib/model/application_links_knowledge_base_iri_template.dart <==
part of keyclic_sdk_api.api;

class ApplicationLinksKnowledgeBaseIriTemplate {
  ApplicationLinksKnowledgeBaseIriTemplate({
    this.mapping,
  });

  factory ApplicationLinksKnowledgeBaseIriTemplate.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return ApplicationLinksKnowledgeBaseIriTemplate(
      mapping: ApplicationLinksKnowledgeBaseIriTemplateMapping.fromJson(
          json['mapping']),
    );
  }

  ApplicationLinksKnowledgeBaseIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is ApplicationLinksKnowledgeBaseIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<ApplicationLinksKnowledgeBaseIriTemplate> listFromJson(
      List<dynamic> json) {
    return json == null
        ? <ApplicationLinksKnowledgeBaseIriTemplate>[]
        : json
            .map((dynamic value) =>
                ApplicationLinksKnowledgeBaseIriTemplate.fromJson(value))
            .toList();
  }

  static Map<String, ApplicationLinksKnowledgeBaseIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    var map = Map<String, ApplicationLinksKnowledgeBaseIriTemplate>();
    if (json != null && json.isNotEmpty) {
      json.forEach((String key, dynamic value) =>
          map[key] = ApplicationLinksKnowledgeBaseIriTemplate.fromJson(value));
    }

    return map;
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping,
    };
  }

  @override
  String toString() {
    return 'ApplicationLinksKnowledgeBaseIriTemplate[mapping=$mapping, ]';
  }
}

==> keyclic_sdk_api-2.3.8.tar.gz: lib/model/application_links_knowledge_base_iri_template.dart <==
part of keyclic_sdk_api.api;

class ApplicationLinksKnowledgeBaseIriTemplate {
  ApplicationLinksKnowledgeBaseIriTemplate({
    this.mapping,
  });

  factory ApplicationLinksKnowledgeBaseIriTemplate.fromJson(
      Map<String, dynamic> json) {
    if (json == null) {
      return null;
    }

    return ApplicationLinksKnowledgeBaseIriTemplate(
      mapping: ApplicationLinksKnowledgeBaseIriTemplateMapping.fromJson(
          json['mapping']),
    );
  }

  ApplicationLinksKnowledgeBaseIriTemplateMapping mapping;

  @override
  bool operator ==(dynamic other) {
    // Same reference
    if (identical(this, other)) {
      return true;
    }

    return other is ApplicationLinksKnowledgeBaseIriTemplate &&
        runtimeType == other.runtimeType &&
        mapping == other.mapping;
  }

  /// By default hashCode return reference
  @override
  int get hashCode {
    int hashCode = 0;

    hashCode ^= mapping?.hashCode ?? 0;

    return hashCode;
  }

  static List<ApplicationLinksKnowledgeBaseIriTemplate> listFromJson(
      List<dynamic> json) {
    return json
            ?.map((dynamic value) =>
                ApplicationLinksKnowledgeBaseIriTemplate.fromJson(value))
            ?.toList() ??
        <ApplicationLinksKnowledgeBaseIriTemplate>[];
  }

  static Map<String, ApplicationLinksKnowledgeBaseIriTemplate> mapFromJson(
      Map<String, dynamic> json) {
    return json?.map((String key, dynamic value) {
          return MapEntry(
              key, ApplicationLinksKnowledgeBaseIriTemplate.fromJson(value));
        }) ??
        <String, ApplicationLinksKnowledgeBaseIriTemplate>{};
  }

  Map<String, dynamic> toJson() {
    return {
      if (mapping != null) 'mapping': mapping.toJson(),
    };
  }

  @override
  String toString() {
    return 'ApplicationLinksKnowledgeBaseIriTemplate[mapping=$mapping, ]';
  }
}
